antares.apps.terminal.migrations package — Antares 0.0.2 documentation

# antares.apps.terminal.migrations package

## Submodules

## antares.apps.terminal.migrations.0001_initial module

class `antares.apps.terminal.migrations.0001_initial.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = []
  `initial` = True
  `operations` = [<CreateModel name='TerminalLog', fields=[('id', <django.db.models.fields.UUIDField>), ('post_date', <django.db.models.fields.DateTimeField>), ('command', <django.db.models.fields.CharField>), ('result', <django.db.models.fields.TextField>)], options={'verbose_name': 'antares.apps.terminal.models.terminal_log.table_name', 'verbose_name_plural': 'antares.apps.terminal.models.terminal_log.table_name_plural', 'db_table': 'adm_terminal_log'}>]

## antares.apps.terminal.migrations.0002_terminallog_author module

## Module contents